@@ -1,4 +1,5 @@
 import json
+import logging
 import os
 import re
 from typing import Dict, List, Optional, Tuple
@@ -14,6 +15,14 @@ CL_COM = "*/"
 IN_COM = "--"
 MYSQL_COM = "#"
 
+logging.basicConfig(
+    level=logging.DEBUG,
+    filename="parselog.txt",
+    filemode="w",
+    format="%(filename)10s:%(lineno)4d:%(message)s",
+)
+log = logging.getLogger()
+
 
 class Parser:
     """
@@ -26,13 +35,17 @@ class Parser:
         Subclass must include tokens for parser and rules
     """
 
-    def __init__(self, content: str) -> None:
+    def __init__(
+        self, content: str, silent: bool = True, normalize_names: bool = False
+    ) -> None:
         """init parser for file"""
         self.tables = []
+        self.silent = silent
         self.data = content.encode("unicode_escape")
         self.paren_count = 0
-        self.lexer = lex.lex(object=self, debug=False)
-        self.yacc = yacc.yacc(module=self, debug=False)
+        self.normalize_names = normalize_names
+        self.lexer = lex.lex(object=self, debug=False, debuglog=log)
+        self.yacc = yacc.yacc(module=self, debug=False, debuglog=log)
         self.columns_closed = False
         self.statement = None
         self.block_comments = []
@@ -225,7 +238,6 @@ class Parser:
 
     def parse_statement(self) -> None:
         _parse_result = yacc.parse(self.statement)
-
         if _parse_result:
             self.tables.append(_parse_result)
 
@@ -240,6 +252,7 @@ class Parser:
             "is_table",
             "last_par",
             "lp_open",
+            "is_alter",
         ]
         for attr in attrs:
             setattr(self.lexer, attr, False)
